@@ -20,5 +20,8 @@
 # Boston, MA 02110-1301 USA,
 
 #python3 -m unittest discover -s tests
-pytest-3 tests
-nosetests3 tests/test_damecsv.py:TestDameCsv.test_damecsv_csvcolumn2list
+echo "Choose pytest or nosetests"
+read test
+
+$test tests
+
