@@ -83,5 +83,14 @@ class TestDameCsv(unittest.TestCase):
         file4 = "files/min.csv"
         self.assertTrue(df.is_csv(file4))
 
+    def test_dta2csv(self):
+        df = DameFormats()
+        file1 = "files/salary.dta"
+        df.dta2csv(file1)
+        self.assertTrue(df.is_csv(file1+".csv"))
+        file2 = "files/gender_JMLA.dta"
+        df.dta2csv(file2)
+        self.assertTrue(df.is_csv(file2+".csv"))
+        
 if __name__ == '__main__':
     unittest.main()
