@@ -24,7 +24,9 @@
 import unittest
 import json
 from netCDF4 import Dataset
-from pprint import pprint
+# fix for MacOS using nose
+import collections
+collections.Callable = collections.abc.Callable
 
 
 class TestDameNetCDF(unittest.TestCase):
